@@ -21,7 +21,7 @@
 import sys, os, re, unittest
 
 main_dir = os.path.split(os.path.abspath(sys.argv[0]))[0]
-test_subdir = 'test'
+test_subdir = os.path.join('pywebsite', 'tests')
 
 # Make sure we're in the correct directory
 os.chdir( main_dir )
